::: ropt.plugins.optimizer
::: ropt.plugins.optimizer.base
    options:
        members:
            - OptimizerPlugin
            - Optimizer
            - OptimizerCallback
::: ropt.plugins.optimizer.utils

